Coverage for /home/chris/workspace/django-shop/shop/models/__init__: 100.00%

# Coverage for /home/chris/workspace/django-shop/shop/models/__init__ : 100.00%

## 6 statements 6 run 0 missing 0 excluded 0 partial

1 2 3 4 5 6 7 8 9 10 | from cartmodel import * from ordermodel import * from productmodel import * from shop.order_signals import * from shop.util.loader import load_class """ Load the class specified by the user as the Address Model. """ AddressModel = load_class(getattr(settings, 'SHOP_ADDRESS_MODEL', 'shop.addressmodel.models.Address'))